# Generated by Django 5.0 on 2023-12-27 16:07

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0021_rename_name_biography_title_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='photogallery',
            name='biography',
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Others', 'Others'), ('budget_development', 'Budget Development'), ('budget_marketing', 'Budget Marketing'), ('budget_design', 'Budget Design'), ('Monthly charge', 'Monthly charge'), ('Billing receipt', 'Billing receipt')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Consulting', 'Consulting'), ('Health and Wellness', 'Health and Wellness'), ('IT Development Services', 'IT Development Services'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Education and Training', 'Education and Training'), ('Media Creators', 'Media Creators'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('E-commerce', 'E-commerce')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue'), ('card-tale', 'card-tale'), ('card-dark-blue', 'card-dark-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Tutorials', 'Tutorials'), ('Guides and Manuals', 'Guides and Manuals'), ('Interviews', 'Interviews'), ('Events and Conferences', 'Events and Conferences'), ('Tips and Tricks', 'Tips and Tricks'), ('News', 'News'), ('Inspiration', 'Inspiration')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 27, 13, 6, 32, 500132)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('No Selected', 'No Selected'), ('Promotional Discount', 'Promotional Discount'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('Initial Payment', 'Initial Payment')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 2', 'Style Template 2'), ('Style Template 4', 'Style Template 4'), ('Style Template 3', 'Style Template 3'), ('Style Template 1', 'Style Template 1')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('No Selected', 'No Selected'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Stela Design', 'Stela Design'), ('Cloud Domains', 'Cloud Domains'), ('Stela Websites', 'Stela Websites'), ('Store', 'Store'), ('Stela Marketing', 'Stela Marketing')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 4', 'Step 4'), ('Step 3', 'Step 3')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('budget_design_terms', 'Budget Design Terms'), ('Cookie Policy', 'Cookie Policy'), ('Return Policy', 'Return Policy'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('budget_development_terms', 'Budget Development Terms'), ('billing_terms', 'Monthly Billing Terms'), ('Privacy Policy', 'Privacy Policy'), ('Disclaimer', 'Disclaimer'), ('monthly_terms', 'Billing Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Tiktok', 'Tiktok'), ('Youtube', 'Youtube'), ('Linkedin', 'Linkedin'), ('Wikipedia', 'Wikipedia'), ('Instagram', 'Instagram'), ('X', 'X'), ('Facebook', 'Facebook'), ('Github', 'Github')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My account has an error', 'My account has an error'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Others', 'Others'), ('Payments Issue', 'Payments Issue'), ('I have a problem with my project', 'I have a problem with my project')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50, null=True),
        ),
        migrations.DeleteModel(
            name='Biography',
        ),
        migrations.DeleteModel(
            name='PhotoGallery',
        ),
    ]
